simultaneous: Simultaneous Model Constructor

View source: R/simultaneous.R

simultaneousR Documentation

Simultaneous Model Constructor

Description

Initialize model object required by the simultaneous methods.

Usage

simultaneous(
  seed = NULL,
  verbose = TRUE,
  init = "svd",
  n_max_iter = 10,
  n_loops = 10,
  tol = 1e-05,
  U_i_g = NULL,
  B_j_q = NULL,
  C_k_r = NULL
)

Arguments

seed

Seed for random sequence generation.

verbose

Flag to display output result for each loop.

init

The initialization method for the model parameters. Values could be 'svd','random','twcfta' or 'twfcta' Defaults to svd.

n_max_iter

Maximum number of iterations to optimize objective function.

n_loops

Number of runs/loops in search of the global result.

tol

Acceptable tolerance level.

U_i_g

Membership function matrix for the objects.

B_j_q

Component matrix for the variables.

C_k_r

Component matrix for the occasions.

Details

Two simultaneous models T3Clus and 3FKMeans are the implemented methods.

  • T3Clus finds B_j_q and C_k_r such that the between-clusters deviance of the component scores is maximized.

  • 3FKMeans finds B_j_q and C_k_r such that the within-clusters deviance of the component scores is minimized.

Value

An object of class "simultaneous".

Note

The model finds the best partition described by the best orthogonal linear combinations of the variables and orthogonal linear combinations of the occasions.

References

\insertRef

tucker1966simuclustfactor \insertRefVichiRocciKierssimuclustfactor

See Also

fit.t3clus fit.3fkmeans fit.ct3clus tandem

Examples

simultaneous()


simuclustfactor documentation built on Oct. 18, 2022, 9:07 a.m.